# Program to generate a scatter plot, and find the best fit polynomial equation.
# Data for arrays x and y are read from a CSV file.
# This code calculates Pearson and Spearman's rank order correlation
# coefficients between the model and experimental data.

# Import libraries
import numpy as np
import matplotlib.pyplot as plt
from scipy.stats import pearsonr, spearmanr

# Read input data
file_in = input("Type CSV file name =>")
degree_pol = int(input("Type an integer for the degree of the polynomial =>"))

# Read CSV file
my_csv = np.genfromtxt (file_in, delimiter=",", skip_header = 1)

# Get each column from a CSV file
x = my_csv[:,0]
y = my_csv[:,1]

# Get the minimum and maximum values of x
x_min = np.min(x)
x_max = np.max(x)

# Set up an axis for the least-square polynomial
x1 = np.linspace(x_min,x_max,1000)

# Generate plot
plt.scatter(x,y,marker= "^",color = "black")

# Least-squares polynomial fitting (degree must be an integer)
z = np.polyfit(x,y,degree_pol)  # Get the equation coefficients
p = np.poly1d(z)                # Generate polynomial equation
print("Best fit polynomial equation: \n",p)

# Calculate Pearson Correlation Coefficient
r, pvalue1 = pearsonr(y,p(x))
print("\nPearson correlation coefficient: %8.3f"%r)
print("p-value: %.4g"%pvalue1)

# Calculate Spearman's Rank-Order Correlation Coefficient
rho, pvalue2 = spearmanr(y,p(x))
print("\nSpearman's rank order correlation coefficient: %8.3f"%rho)
print("p-value: %.4g"%pvalue2)

# Generate plot
plt.plot(x1,p(x1),color = "blue")

# Show plot
plt.show()

# Some editing of the file_in string
file_out = file_in[:len(file_in)-4]

# Save plot on png file
plt.savefig(file_out+'_degree_pol_'+str(degree_pol)+'.png')